\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ibz-document}
\LoadClass[
11pt,
a4paper
]{article}

\RequirePackage[
left=3cm,
right=3cm,
top=3cm,
bottom=3cm
]{geometry}

%Font settings
\RequirePackage[default]{sourcesanspro}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}		% Latin Modern Fonts (without Bold Smal Capital Font)
\RequirePackage{slantsc}			% Smal Capital Letters

%Enable Mathsupport
\RequirePackage{mathtools}
\mathtoolsset{showonlyrefs}
%Use normal font for math
\RequirePackage{mathastext}		%[defaultmathsizes]

%Support for German
\RequirePackage[utf8]{inputenc}
\RequirePackage{ngerman}

%Header & Footer styling
\RequirePackage{lastpage} % number of last page 
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\lhead{\HeaderLeft}
\chead{\HeaderCenter}
\rhead{\HeaderRight}
\lfoot{\FooterLeft}
\cfoot{\FooterCenter}
\rfoot{\FooterRight}
\renewcommand{\headrulewidth}{1pt} %0pt for no rule, 2pt thicker etc...
\renewcommand{\footrulewidth}{0pt}
\setlength{\headheight}{16pt} 

%TOC
\RequirePackage[tocflat]{tocstyle} %is alpha but it solves the indent on sectons
\usetocstyle{standard} 
\renewcommand\tableofcontents{%
  \null\hfill\textbf{\Large\contentsname}\hfill\null\par
  \@mkboth{\MakeUppercase\contentsname}{\MakeUppercase\contentsname}%
  \@starttoc{toc}%
}
%Index
\RequirePackage{imakeidx} % Word Index
\makeindex 

\setlength{\parskip}{\baselineskip}% paragraph sprung 
\setlength{\parindent}{0pt}% paragraph einzug
\linespread{1.2}%Make line spacing bigger

%Make whitespace in tables bigger
\renewcommand\arraystretch{1.5}

%Enable colours for tables
\RequirePackage[table]{xcolor}

%Needed to rotate graphics and tables
\RequirePackage{rotating}

%Support for images
%\RequirePackage{graphicx} % is included in tikz

%Support for Graphics
\RequirePackage{tikz}

%Enable URL highlighting
\RequirePackage{hyperref}
\hypersetup{
    colorlinks=true,
    linkcolor=black,
    urlcolor=blue,
}
\urlstyle{same}

%Material theme colours
\definecolor{red}{HTML}{F44336}
\definecolor{pink}{HTML}{E91E63}
\definecolor{purple}{HTML}{9C27B0}
%\definecolor{blue}{HTML}{2196F3}
\definecolor{brown}{HTML}{795548}
\definecolor{cyan}{HTML}{00BCD4}
\definecolor{darkgray}{HTML}{616161}
\definecolor{gray}{HTML}{9E9E9E}
\definecolor{lightgray}{HTML}{E0E0E0}
\definecolor{lime}{HTML}{CDDC39}
\definecolor{olive}{HTML}{827717}
\definecolor{orange}{HTML}{FF9800}
\definecolor{teal}{HTML}{009688}
\definecolor{yellow}{HTML}{FFEB3B}
\definecolor{green}{HTML}{388E3C}

% Document Variable-Set finetuned
\author{\authorname}
\title{\titlepre\titleseparator\titlename}
\date{\today}



